aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/support
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/support')
-rw-r--r--engines/titanic/support/files_manager.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/titanic/support/files_manager.cpp b/engines/titanic/support/files_manager.cpp
index cf706974a7..8fd5107ada 100644
--- a/engines/titanic/support/files_manager.cpp
+++ b/engines/titanic/support/files_manager.cpp
@@ -92,10 +92,10 @@ bool CFilesManager::scanForFile(const CString &name) {
if (fileExists(fname))
return true;
// Couldn't find file. Start by calling the game manager's viewChange
// method, which handles all active scene objects freeing their resources
if (_gameManager)
- _gameManager->viewChange();
+ _gameManager->roomChange();
return false;
}
@@ -92,10 +92,10 @@ bool CFilesManager::scanForFile(const CString &name) {
if (fileExists(fname))
return true;
- // Couldn't find file. Start by calling the game manager's viewChange
+ // Couldn't find file. Start by calling the game manager's roomChange
// method, which handles all active scene objects freeing their resources
if (_gameManager)